/*
 * util_funcs/MIB_STATS_CACHE_TIMEOUT.h:  utilitiy functions for extensible
 * groups.
 */
#ifndef _MIBGROUP_UTIL_FUNCS_MIB_STATS_CACHE_TIMEOUT_H
#define _MIBGROUP_UTIL_FUNCS_MIB_STATS_CACHE_TIMEOUT_H

#ifndef MIB_STATS_CACHE_TIMEOUT
#define MIB_STATS_CACHE_TIMEOUT 5
#endif

#endif /* _MIBGROUP_UTIL_FUNCS_MIB_STATS_CACHE_TIMEOUT_H */
